#
# Configuration file for using the XML library in GNOME applications
#
XML_LIBDIR="-L/usr/local/lib"
XML_LIBS="-lxml -lz  "
XML_INCLUDEDIR="-I/usr/local/include/gnome-xml"
MODULE_VERSION="xml-1.8.17"

